==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaDyiqLs.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description  地役权属性
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
		name = "ba_dyiq_ls"
)
public class BaDyiqLs implements Serializable {

	@XmlAttribute
	@Id
	@id
	private String id;


	@XmlAttribute
	private String ysdm;

	@XmlAttribute
	@Nullable
	@ywh
	private String ywh;

	@XmlAttribute
	private String gydbdcdyh;

	@XmlAttribute
	@encrypt
	private String gydqlr;

	@XmlAttribute
	@Nullable
	private String gydqlrzjzl;

	@XmlAttribute
	@Nullable
	@encrypt
	private String gydqlrzjh;

	@XmlAttribute
	private String xydbdcdyh;

	@XmlAttribute
	private String xydzl;

	@XmlAttribute
	@encrypt
	private String xydqlr;

	@XmlAttribute
	@Nullable
	private String xydqlrzjzl;

	@XmlAttribute
	@Nullable
	@encrypt
	private String xydqlrzjh;

	@XmlAttribute
	private String djlx;

	@XmlAttribute
	private String djyy;

	@XmlAttribute
	private String dyqnr;

	@XmlAttribute
	private String bdcdjzmh;

	@XmlAttribute
	@Nullable
	private Date qlqssj;

	@XmlAttribute
	@Nullable
	private Date qljssj;

	@XmlAttribute
	private String qxdm;

	@XmlAttribute
	private String djjg;

	@XmlAttribute
	private String dbr;

	@XmlAttribute
	private Date djsj;

	@XmlAttribute
	@Nullable
	private String fj;

	@XmlAttribute
	private String qszt;

	@XmlAttribute
	@Transient
	private  String xydqlrzjzh;

	@Nullable
	private Date sjgxsj;

	@bwmc
	private String bwmc;

	@XmlAttribute
	private String ssywh;

	@XmlAttribute
	private String qlqx;

	/**
	 * @author <a href="mailto:huming@gtmap.cn">huming</a>
	 * @description 注销报文名称
	 */
	private String zxbwmc;

	@sqlx
	private String sqlx;

	public String getSqlx() {
		return sqlx;
	}

	public void setSqlx(String sqlx) {
		this.sqlx = sqlx;
	}

	public String getZxbwmc() {
		return zxbwmc;
	}

	public void setZxbwmc(String zxbwmc) {
		this.zxbwmc = zxbwmc;
	}

	public String getSsywh() {
		return ssywh;
	}

	public void setSsywh(String ssywh) {
		this.ssywh = ssywh;
	}

	public String getQlqx() {
		return qlqx;
	}

	public void setQlqx(String qlqx) {
		this.qlqx = qlqx;
	}

	public String getBwmc() {
		return bwmc;
	}

	public void setBwmc(String bwmc) {
		this.bwmc = bwmc;
	}
	public Date getSjgxsj() {
		return sjgxsj;
	}

	public void setSjgxsj(Date sjgxsj) {
		this.sjgxsj = sjgxsj;
	}

	public String getYsdm() {
		return ysdm;
	}

	public String getYwh() {
		return ywh;
	}

	public String getGydbdcdyh() {
		return gydbdcdyh;
	}

	public String getGydqlr() {
		return gydqlr;
	}

	public String getGydqlrzjzl() {
		return gydqlrzjzl;
	}

	public String getGydqlrzjh() {
		return gydqlrzjh;
	}

	public String getXydbdcdyh() {
		return xydbdcdyh;
	}

	public String getXydzl() {
		return xydzl;
	}

	public String getXydqlr() {
		return xydqlr;
	}

	public String getXydqlrzjzl() {
		return xydqlrzjzl;
	}

	public String getXydqlrzjh() {
		return xydqlrzjh;
	}

	public String getDjlx() {
		return djlx;
	}

	public String getDjyy() {
		return djyy;
	}

	public String getDyqnr() {
		return dyqnr;
	}

	public String getBdcdjzmh() {
		return bdcdjzmh;
	}

	public Date getQlqssj() {
		return qlqssj;
	}

	public Date getQljssj() {
		return qljssj;
	}

	public String getQxdm() {
		return qxdm;
	}

	public String getDjjg() {
		return djjg;
	}

	public String getDbr() {
		return dbr;
	}

	public Date getDjsj() {
		return djsj;
	}

	public String getFj() {
		return fj;
	}

	public String getQszt() {
		return qszt;
	}


	public void setYsdm(String ysdm) {
		this.ysdm = ysdm;
	}

	public void setYwh(String ywh) {
		this.ywh = ywh;
	}

	public void setGydbdcdyh(String gydbdcdyh) {
		this.gydbdcdyh = gydbdcdyh;
	}

	public void setGydqlr(String gydqlr) {
		this.gydqlr = gydqlr;
	}

	public void setGydqlrzjzl(String gydqlrzjzl) {
		this.gydqlrzjzl = gydqlrzjzl;
	}

	public void setGydqlrzjh(String gydqlrzjh) {
		this.gydqlrzjh = gydqlrzjh;
	}

	public void setXydbdcdyh(String xydbdcdyh) {
		this.xydbdcdyh = xydbdcdyh;
	}

	public void setXydzl(String xydzl) {
		this.xydzl = xydzl;
	}

	public void setXydqlr(String xydqlr) {
		this.xydqlr = xydqlr;
	}

	public void setXydqlrzjzl(String xydqlrzjzl) {
		this.xydqlrzjzl = xydqlrzjzl;
	}

	public void setXydqlrzjh(String xydqlrzjh) {
		this.xydqlrzjh = xydqlrzjh;
	}

	public void setDjlx(String djlx) {
		this.djlx = djlx;
	}

	public void setDjyy(String djyy) {
		this.djyy = djyy;
	}

	public void setDyqnr(String dyqnr) {
		this.dyqnr = dyqnr;
	}

	public void setBdcdjzmh(String bdcdjzmh) {
		this.bdcdjzmh = bdcdjzmh;
	}

	public void setQlqssj(Date qlqssj) {
		this.qlqssj = qlqssj;
	}

	public void setQljssj(Date qljssj) {
		this.qljssj = qljssj;
	}

	public void setQxdm(String qxdm) {
		this.qxdm = qxdm;
	}

	public void setDjjg(String djjg) {
		this.djjg = djjg;
	}

	public void setDbr(String dbr) {
		this.dbr = dbr;
	}

	public void setDjsj(Date djsj) {
		this.djsj = djsj;
	}

	public void setFj(String fj) {
		this.fj = fj;
	}

	public void setQszt(String qszt) {
		this.qszt = qszt;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getXydqlrzjzh() {
		return xydqlrzjzh;
	}

	public void setXydqlrzjzh(String xydqlrzjzh) {
		this.xydqlrzjzh = xydqlrzjzh;
	}
}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/entity/BaDyiqLs.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description  地役权属性
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
		name = "ba_dyiq_ls"
)
public class BaDyiqLs implements Serializable {

	@XmlAttribute
	@Id
	@id
	private String id;


	@XmlAttribute
	private String ysdm;

	@XmlAttribute
	@Nullable
	@ywh
	private String ywh;

	@XmlAttribute
	private String gydbdcdyh;

	@XmlAttribute
	@encrypt
	private String gydqlr;

	@XmlAttribute
	@Nullable
	private String gydqlrzjzl;

	@XmlAttribute
	@Nullable
	@encrypt
	private String gydqlrzjh;

	@XmlAttribute
	private String xydbdcdyh;

	@XmlAttribute
	private String xydzl;

	@XmlAttribute
	@encrypt
	private String xydqlr;

	@XmlAttribute
	@Nullable
	private String xydqlrzjzl;

	@XmlAttribute
	@Nullable
	@encrypt
	private String xydqlrzjh;

	@XmlAttribute
	private String djlx;

	@XmlAttribute
	private String djyy;

	@XmlAttribute
	private String dyqnr;

	@XmlAttribute
	private String bdcdjzmh;

	@XmlAttribute
	@Nullable
	private Date qlqssj;

	@XmlAttribute
	@Nullable
	private Date qljssj;

	@XmlAttribute
	private String qxdm;

	@XmlAttribute
	private String djjg;

	@XmlAttribute
	private String dbr;

	@XmlAttribute
	private Date djsj;

	@XmlAttribute
	@Nullable
	private String fj;

	@XmlAttribute
	private String qszt;

	@XmlAttribute
	@Transient
	private  String xydqlrzjzh;

	@Nullable
	private Date sjgxsj;

	@bwmc
	private String bwmc;

	@XmlAttribute
	private String ssywh;

	@XmlAttribute
	private String qlqx;

	/**
	 * @author <a href="mailto:huming@gtmap.cn">huming</a>
	 * @description 注销报文名称
	 */
	private String zxbwmc;

	@sqlx
	private String sqlx;

	// ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

	/** 注销时间 */
	@XmlAttribute
	private Date zxsj;

	/** 原不动产单元号 */
	@XmlAttribute
	private String ybdcdyh;

	/** 用地用海分类代码 */
	@XmlAttribute
	private String ydyhfldm;

	// ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

	public String getSqlx() {
		return sqlx;
	}

	public void setSqlx(String sqlx) {
		this.sqlx = sqlx;
	}

	public String getZxbwmc() {
		return zxbwmc;
	}

	public void setZxbwmc(String zxbwmc) {
		this.zxbwmc = zxbwmc;
	}

	public String getSsywh() {
		return ssywh;
	}

	public void setSsywh(String ssywh) {
		this.ssywh = ssywh;
	}

	public String getQlqx() {
		return qlqx;
	}

	public void setQlqx(String qlqx) {
		this.qlqx = qlqx;
	}

	public String getBwmc() {
		return bwmc;
	}

	public void setBwmc(String bwmc) {
		this.bwmc = bwmc;
	}
	public Date getSjgxsj() {
		return sjgxsj;
	}

	public void setSjgxsj(Date sjgxsj) {
		this.sjgxsj = sjgxsj;
	}

	public String getYsdm() {
		return ysdm;
	}

	public String getYwh() {
		return ywh;
	}

	public String getGydbdcdyh() {
		return gydbdcdyh;
	}

	public String getGydqlr() {
		return gydqlr;
	}

	public String getGydqlrzjzl() {
		return gydqlrzjzl;
	}

	public String getGydqlrzjh() {
		return gydqlrzjh;
	}

	public String getXydbdcdyh() {
		return xydbdcdyh;
	}

	public String getXydzl() {
		return xydzl;
	}

	public String getXydqlr() {
		return xydqlr;
	}

	public String getXydqlrzjzl() {
		return xydqlrzjzl;
	}

	public String getXydqlrzjh() {
		return xydqlrzjh;
	}

	public String getDjlx() {
		return djlx;
	}

	public String getDjyy() {
		return djyy;
	}

	public String getDyqnr() {
		return dyqnr;
	}

	public String getBdcdjzmh() {
		return bdcdjzmh;
	}

	public Date getQlqssj() {
		return qlqssj;
	}

	public Date getQljssj() {
		return qljssj;
	}

	public String getQxdm() {
		return qxdm;
	}

	public String getDjjg() {
		return djjg;
	}

	public String getDbr() {
		return dbr;
	}

	public Date getDjsj() {
		return djsj;
	}

	public String getFj() {
		return fj;
	}

	public String getQszt() {
		return qszt;
	}


	public void setYsdm(String ysdm) {
		this.ysdm = ysdm;
	}

	public void setYwh(String ywh) {
		this.ywh = ywh;
	}

	public void setGydbdcdyh(String gydbdcdyh) {
		this.gydbdcdyh = gydbdcdyh;
	}

	public void setGydqlr(String gydqlr) {
		this.gydqlr = gydqlr;
	}

	public void setGydqlrzjzl(String gydqlrzjzl) {
		this.gydqlrzjzl = gydqlrzjzl;
	}

	public void setGydqlrzjh(String gydqlrzjh) {
		this.gydqlrzjh = gydqlrzjh;
	}

	public void setXydbdcdyh(String xydbdcdyh) {
		this.xydbdcdyh = xydbdcdyh;
	}

	public void setXydzl(String xydzl) {
		this.xydzl = xydzl;
	}

	public void setXydqlr(String xydqlr) {
		this.xydqlr = xydqlr;
	}

	public void setXydqlrzjzl(String xydqlrzjzl) {
		this.xydqlrzjzl = xydqlrzjzl;
	}

	public void setXydqlrzjh(String xydqlrzjh) {
		this.xydqlrzjh = xydqlrzjh;
	}

	public void setDjlx(String djlx) {
		this.djlx = djlx;
	}

	public void setDjyy(String djyy) {
		this.djyy = djyy;
	}

	public void setDyqnr(String dyqnr) {
		this.dyqnr = dyqnr;
	}

	public void setBdcdjzmh(String bdcdjzmh) {
		this.bdcdjzmh = bdcdjzmh;
	}

	public void setQlqssj(Date qlqssj) {
		this.qlqssj = qlqssj;
	}

	public void setQljssj(Date qljssj) {
		this.qljssj = qljssj;
	}

	public void setQxdm(String qxdm) {
		this.qxdm = qxdm;
	}

	public void setDjjg(String djjg) {
		this.djjg = djjg;
	}

	public void setDbr(String dbr) {
		this.dbr = dbr;
	}

	public void setDjsj(Date djsj) {
		this.djsj = djsj;
	}

	public void setFj(String fj) {
		this.fj = fj;
	}

	public void setQszt(String qszt) {
		this.qszt = qszt;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getXydqlrzjzh() {
		return xydqlrzjzh;
	}

	public void setXydqlrzjzh(String xydqlrzjzh) {
		this.xydqlrzjzh = xydqlrzjzh;
	}

	public Date getZxsj() {
		return zxsj;
	}

	public void setZxsj(Date zxsj) {
		this.zxsj = zxsj;
	}

	public String getYbdcdyh() {
		return ybdcdyh;
	}

	public void setYbdcdyh(String ybdcdyh) {
		this.ybdcdyh = ybdcdyh;
	}

	public String getYdyhfldm() {
		return ydyhfldm;
	}

	public void setYdyhfldm(String ydyhfldm) {
		this.ydyhfldm = ydyhfldm;
	}
}
